@@ -6,12 +6,12 @@ import sys
 from typing import Optional
 
 import openai
-from colorama import Fore
-from colorama import init as colorama_init
+import questionary as q
 
 from cliai.config import create_or_update_config, load_config
-from cliai.convo import (MessageList, load_convo, make_request, retry_request,
-                         save_convo, stylize_response)
+from cliai.convo import MessageList, load_convo, make_request, save_convo
+from cliai.util import (print_not_implemented, print_response, print_success,
+                        print_warning, print_role)
 
 
 def metainitiate():
@@ -27,8 +27,6 @@ def initiate(api_key: Optional[str] = None):
     """
     Function to initiate the CLI application.
     """
-    colorama_init(autoreset=True)
-
     if api_key:
         auth(api_key)
     elif api_env := os.getenv('OPENAI_API_KEY'):
@@ -60,56 +58,66 @@ def auth(api_key: str) -> None:
     openai.api_key = api_key
 
     if is_authenticated():
-        print(Fore.GREEN + '\nAuthenticated!\n')
+        print_success('\tAuthenticated!\n')
     else:
-        print(Fore.RED + 'Incorrect API key provided!')
+        print_warning('Incorrect API key provided!')
 
 
 def converse(messages: Optional[MessageList] = None,
              verbose: Optional[bool] = 0) -> None:
+    """
+    Start chatting.
+    """
     if not is_authenticated():
         initiate()
 
     if messages is None:
         messages = MessageList()
 
-    # TODO: ask for system
-    pass
+    print('Welcome to chat mode.\n')
 
-    try:
-        # TODO: Add a counter?
-        print('Welcome to chat mode.\nType to chat, double press <Enter> to send, <Ctrl-C> to quit.\n')
+    # Ask if to use custom system role
+    if not q.confirm('Use the default system role?').ask():
+        print_not_implemented()
+
+    # Chat while true
+    while True:
+        # Ask for user input
+        user_says = q.text('', qmark='[User]', multiline=True).ask()
+        messages.user_says(user_says)
+        print()
+
+        # Make the resquest while true
         while True:
-            # Ask for user input
-            print('User: ')
-            user_says = ''
-            while True:
-                user_says += input('\t') + '\n'
-                if user_says[-2:] == '\n\n':
-                    break
-            messages.user_says(user_says)
-
             response = make_request(messages)
-            finish_reason = response.choices[0].finish_reason 
+            finish_reason = response.choices[0].finish_reason
+
             if finish_reason == 'stop':
                 assistant_says = response.choices[0].message.content
+
                 if verbose:
-                    print(
-                        f'Assistant (in {response.response_ms}): {stylize_response(assistant_says)}'
-                    )
-                else:
-                    print(f'Assistant:\n\t{stylize_response(assistant_says)}')
-                messages.assistant_says(assistant_says)
+                    # TODO: Add a counter?
+                    print(f'In {response.response_ms}')
+
+                print_role('Assistant')
+                print_response(assistant_says)
+
+                user_reaction = q.select('Next', choices=['Continue', 'Retry', 'Quit']).ask()
+
+                if user_reaction == 'Continue':
+                    messages.assistant_says(assistant_says)
+                    print()
+                    break
+
+                # elif user_reaction == 'Modify':
+
+                elif user_reaction == 'Quit':
+                    print()
+                    if q.confirm('Save this conversation?').ask():
+                        save_convo(messages)
+                    sys.exit()
+
             elif finish_reason == 'length':
-                print(Fore.YELLOW + 'Maximum length reached.')
-            else:
-                retry_request()
+                q.confirm('Maximum length reached. Retry?').ask()
 
             print()
-
-    except KeyboardInterrupt:
-        if_save = bool(input(Fore.YELLOW +
-                             '\nSave this conversation? (y/N): '))
-        if if_save:
-            save_convo(messages)
-        sys.exit()
